@@ -25,7 +25,7 @@
 /*! \file arr.h
  *  Various high-performance array classes used by the Planck LevelS package.
  *
- *  Copyright (C) 2002-2012 Max-Planck-Society
+ *  Copyright (C) 2002-2014 Max-Planck-Society
  *  \author Martin Reinecke
  */
 
@@ -359,6 +359,10 @@ template <typename T, typename storageManager> class arr2T
       : s1(sz1), s2(sz2), d(s1*s2) {}
     /*! Creates an array with the dimensions  \a sz1 and \a sz2
         and initializes them with \a inival. */
+    /*! Creates an array with the dimensions \a sz1 and \a sz2 from existing
+        pointer. */
+    arr2T(T* p, tsize sz1, tsize sz2)
+      : s1(sz1), s2(sz2), d(p, s1*s2) {}
     arr2T(tsize sz1, tsize sz2, const T &inival)
       : s1(sz1), s2(sz2), d (s1*s2)
       { fill(inival); }
@@ -475,6 +479,9 @@ template <typename T>
     arr2() : arr2T<T,normalAlloc__<T> > () {}
     /*! Creates an array with the dimensions \a sz1 and \a sz2. */
     arr2(tsize sz1, tsize sz2) : arr2T<T,normalAlloc__<T> > (sz1,sz2) {}
+    /*! Creates an array with the dimensions \a sz1 and \a sz2 from existing
+        pointer. */
+    arr2(T* p, tsize sz1, tsize sz2) : arr2T<T,normalAlloc__<T> > (p,sz1,sz2) {}
     /*! Creates an array with the dimensions  \a sz1 and \a sz2
         and initializes them with \a inival. */
     arr2(tsize sz1, tsize sz2, const T &inival)
